@@ -5,6 +5,7 @@ from navertoon.toon import test_navertoon
 from kofia.crawler import test_kofia
 from druginfo.crawler import test_druginfo
 from costores.crawler import coscores_search
+from naverplace.crawler import test_place
 
 
 def main():
@@ -39,6 +40,9 @@ def main():
     
     if args.appname == 'coscores':
         coscores_search(search=args.search)
+
+    if args.appname == 'naverplace':
+        test_place()
         
 
 
